tendril.gedaif package
======================

Submodules
----------

.. toctree::

   tendril.gedaif.bomparser
   tendril.gedaif.conffile
   tendril.gedaif.gerberfiles
   tendril.gedaif.gschem
   tendril.gedaif.gsymlib
   tendril.gedaif.pcb
   tendril.gedaif.projfile
   tendril.gedaif.validate

Module contents
---------------

.. automodule:: tendril.gedaif
    :members:
    :undoc-members:
    :show-inheritance:

Inheritance Diagram
-------------------

.. inheritance-diagram::
   tendril.gedaif
   tendril.gedaif.bomparser
   tendril.gedaif.conffile
   tendril.gedaif.gschem
   tendril.gedaif.gsymlib
   tendril.gedaif.pcb
   tendril.gedaif.projfile
   tendril.gedaif.validate
